MlDsaSignerVariant

Enum MlDsaSignerVariant 

pub enum MlDsaSignerVariant {
    MlDsa44(MlDsaSigner<MlDsa44>),
    MlDsa65(MlDsaSigner<MlDsa65>),
    MlDsa87(MlDsaSigner<MlDsa87>),
}
Signer variant that dispatches to the correct ML-DSA parameter set. Returned by load_ml_dsa_signer_from_pkcs8_der when the parameter set is auto-detected from the PKCS#8 AlgorithmIdentifier OID.

Variants



MlDsa44(MlDsaSigner<MlDsa44>)



MlDsa65(MlDsaSigner<MlDsa65>)



MlDsa87(MlDsaSigner<MlDsa87>)

Implementations

Source

impl MlDsaSignerVariant

pub fn algorithm_name(&self) -> &'static str

pub fn demo(sig_alg: &str) -> Result<Self, String>

Construct a demo signer with a random seed for the given algorithm name.

pub fn sign_bundle( &mut self, ca: &CaIdentity, snapshot: &StatusSnapshot, config: &GenerationConfig, seal_fn: impl FnOnce(&[u8]) -> Result<Vec<u8>>, responder_cert_der: Option<&[u8]>, ) -> Result<Vec<u8>>

Produce an ahu bundle, dispatching to the correct monomorphized produce_bundle instantiation based on the loaded parameter set.